@@ -20,13 +20,13 @@
   see also: 
 
   + W. Baumgartner, P. Weiss, H. Schindler, 'A Nonparametric Test for the General Two-Sample Problem', 
-    Biometrics, Vol. 54, No. 3 (Sep., 1998), pp. 1129-1135. http://doai.io/10.2307/2533862
+    Biometrics, Vol. 54, No. 3 (Sep., 1998), pp. 1129-1135. \doi{10.2307/2533862}
   + M. Neuhauser, 'Exact Tests Based on the Baumgartner-Weiss-Schindler Statistic--A Survey', 
-    Statistical Papers, Vol 46 (2005), pp. 1-30. http://doai.io/10.1007/BF02762032
+    Statistical Papers, Vol 46 (2005), pp. 1-30. \doi{10.1007/BF02762032}
   + M. Neuhauser, 'One-Sided Two-Sample and Trend Tests Based on a Modified Baumgartner-Weiss-Schindler 
-    Statistic', J. Nonparametric Statistics, Vol 13 (2001) pp 729-739. http://doai.io/10.1080/10485250108832874
+    Statistic', J. Nonparametric Statistics, Vol 13 (2001) pp 729-739. \doi{10.1080/10485250108832874}
   + H. Murakami, 'K-Sample Rank Test Based on Modified Baumgartner Statistic and its Power Comparison', 
-    J. Jpn. Comp. Statist. Vol 19 (2006), pp. 1-13. http://doai.io/10.1080/00949655.2010.551516
+    J. Jpn. Comp. Statist. Vol 19 (2006), pp. 1-13. \doi{10.1080/00949655.2010.551516}
 
 
   Created: 2016.04.06
@@ -171,7 +171,7 @@ double gamrat(double j) {
 //' bvals <- replicate(500, bws_stat(rnorm(50),rnorm(50)))
 //' pvals <- bws_cdf(bvals)
 //' # these should be uniform!
-//' \dontrun{ 
+//' \donttest{ 
 //'   plot(ecdf(pvals)) 
 //' }
 //' 
